<?php
// library to transform a gregorian date to a GMT Maya Long Count

/* \brief Transform the Unix time $t into a GMT Maya Long Count representation.
 *
 * The result is a string of 5 numbers.
 *
 * The input time can be negative.
 *
 * \param[in] $t A unix time in seconds since Jan 1, 1970
 *
 * \return The time $t in GMT Maya Long Count representation
 */
function date_to_maya($t) {
  // we remove the seconds, minutes and hours
  $t = floor($t / 86400);

  // Adjust the number to match the number of days in Maya Long Count
  $t += 1856305;

  // Compute the result
  $kin = $t % 20;
  $t /= 20;
  $winal = $t % 18;
  $t /= 18;
  $tun = $t % 20;
  $t /= 20;
  $katun = $t % 20;
  $t /= 20;
  $baktun = $t % 20; // goes back to 0 on Dec 21, 2012

  // return the result in modern writing
  return "{$baktun}.{$katun}.{$tun}.{$winal}.{$kin}";
}

